@@ -4,8 +4,8 @@ package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback;
 BEGIN {
   $Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::AUTHORITY = 'cpan:ETHER';
 }
-# git description: v0.001-5-g1bd0b13
-$Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::VERSION = '0.002';
+# git description: v0.003-1-g37f53d3
+$Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::VERSION = '0.004';
 # ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # vim: set ts=8 sw=4 tw=78 et :
 
@@ -24,6 +24,10 @@ use List::Util 'first';
 use Scalar::Util 'blessed';
 use namespace::autoclean;
 
+has [qw(mb_version mbt_version)] => (
+    is  => 'ro', isa => 'Str',
+);
+
 has plugins => (
     isa => ArrayRef[role_type('Dist::Zilla::Role::BuildPL')],
     lazy => 1,
@@ -32,8 +36,8 @@ has plugins => (
         my @plugins = @{ $self->zilla->plugins };
         my %args = ( plugin_name => 'ModuleBuildTiny::Fallback', zilla => $self->zilla );
         [
-            Dist::Zilla::Plugin::ModuleBuild->new(%args),
-            Dist::Zilla::Plugin::ModuleBuildTiny->new(%args),
+            Dist::Zilla::Plugin::ModuleBuild->new(%args, $self->mb_version ? ( mb_version => $self->mb_version ) : ()),
+            Dist::Zilla::Plugin::ModuleBuildTiny->new(%args, $self->mbt_version ? ( version => $self->mbt_version ) : ()),
         ]
     },
     traits => ['Array'],
@@ -75,7 +79,11 @@ sub gather_files
 sub register_prereqs
 {
     my $self = shift;
-    $_->register_prereqs foreach $self->plugins;
+
+    # we don't need MB's configure_requires because if Module::Build runs,
+    # configure_requires wasn't being respected anyway
+    my ($mb, $mbt) = $self->plugins;
+    $mbt->register_prereqs;
 }
 
 sub setup_installer
@@ -215,9 +223,15 @@ __PACKAGE__->meta->make_immutable;
 #pod
 #pod =head1 CONFIGURATION OPTIONS
 #pod
-#pod None of the configuration options of the
-#pod L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny>
-#pod or L<[ModuleBuild]|Dist::Zilla::Plugin::ModuleBuild> plugins are exposed at this time.
+#pod =head2 mb_version
+#pod
+#pod Optional.
+#pod Passed to L<[ModuleBuild]|Dist::Zilla::Plugin::ModuleBuild>.
+#pod
+#pod =head2 mbt_version
+#pod
+#pod Optional.
+#pod Passed to L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny> as C<version>.
 #pod
 #pod =head1 SUPPORT
 #pod
@@ -255,7 +269,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Modu
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -327,9 +341,15 @@ F<Build.PL> for the distribution.
 
 =head1 CONFIGURATION OPTIONS
 
-None of the configuration options of the
-L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny>
-or L<[ModuleBuild]|Dist::Zilla::Plugin::ModuleBuild> plugins are exposed at this time.
+=head2 mb_version
+
+Optional.
+Passed to L<[ModuleBuild]|Dist::Zilla::Plugin::ModuleBuild>.
+
+=head2 mbt_version
+
+Optional.
+Passed to L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny> as C<version>.
 
 =head1 SUPPORT
 
